# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['airflow_dvc',
 'airflow_dvc.cli',
 'airflow_dvc.plugin',
 'airflow_dvc.plugin.platforms']

package_data = \
{'': ['*'], 'airflow_dvc.plugin': ['templates/dvc/*']}

install_requires = \
['GitPython>=3.1.14,<4.0.0',
 'SQLAlchemy<1.4.0',
 'apache-airflow-providers-amazon>=1.3.0,<2.0.0',
 'apache-airflow>=2.0.0',
 'semantic-version>=2.8.5,<3.0.0',
 'semver>=2.13.0,<3.0.0',
 'toml>=0.10.2,<0.11.0',
 'typer>=0.3.2,<0.4.0']

entry_points = \
{'airflow.plugins': ['airflow_dvc_plugin = airflow_dvc:DVCPlugin'],
 'console_scripts': ['airflow_dvc = airflow_dvc.cli.entrypoint:run_cli',
                     'publish = publish:publish']}

setup_kwargs = {
    'name': 'airflow-dvc',
    'version': '1.6.0',
    'description': 'DVC operator for Airflow',
    'long_description': '# Airflow DVC (1.6.0)\n\n[![PyPI](https://img.shields.io/pypi/v/airflow-dvc?style=flat-square)](https://pypi.org/project/airflow-dvc/)\n[![GitHub commit activity](https://img.shields.io/github/commit-activity/m/covid-genomics/airflow-dvc?style=flat-square)](https://github.com/covid-genomics/airflow-dvc/commits/master)\n\n\nThis is an [Airflow](https://airflow.apache.org/) extension that adds support for [DVC](https://dvc.org/doc) operations.\n\n<a href="https://covidgenomics.com/">\n<img src="https://github.com/covid-genomics/airflow-dvc/blob/master/static/cg_logo.png?raw=true" width="200px"/>\n</a>\n\n\n## Installation\n\nTo install this package please do:\n```bash\n  $ python3 -m pip install "airflow-dvc==1.6.0"\n```\n\nOr if you are using [Poetry](https://python-poetry.org/) to run Apache Airflow:\n```bash\n  $ poetry add apache-airflow@latest\n  $ poetry add "airflow-dvc@1.6.0"\n```\n\n## What this package provides?\n\nThe package provides the following core features:\n* 📊 [DVC Operator view](https://github.com/covid-genomics/airflow-dvc#-dvc-operator-view) (tab to browse all configured DVC operators)\n* 💾 [DVCUpdateOperator](https://github.com/covid-genomics/airflow-dvc#-dvcupdateoperator-uploading) (for uploading data to DVC)\n* ⬇️ [DVCDownloadOperator](https://github.com/covid-genomics/airflow-dvc#%EF%B8%8F-dvcdownloadoperator-downloading) (for downloading data from DVC)\n* 👀 [DVCUpdateSensor](https://github.com/covid-genomics/airflow-dvc#-dvcsensor) (for waiting for a file modification on DVC)\n* 🤖 [DVCHook](https://github.com/covid-genomics/airflow-dvc#-dvchook) (high-level client for DVC)\n\n## Run examples yourself\n\nThe examples are provided in the `example/` directory.\nPlease do the following to setup quick Airflow demo:\n```bash\n  # Your git repo clone URL\n  # Example:\n  #   REPO="https://GITHUB_PERSONAL_TOKEN@github.com/OWNER/REPO.git"\n  $ export REPO="<YOUR_REPO_URL>"\n\n  # Install Airflow with Poetry\n  $ mkdir airflow-dvc-test && cd airflow-dvc-test\n  $ poetry init\n  $ poetry add apache-airflow "airflow-dvc@1.6.0"\n  \n  # Configure Airflow paths\n  $ export AIRFLOW_HOME=$(pwd)/airflow\n  $ export AIRFLOW_CONFIG=$AIRFLOW_HOME/airflow.cfg\n  $ mkdir -p $AIRFLOW_HOME > /dev/null 2> /dev/null\n  \n  # Init Airflow\n  $ poetry run airflow db init\n  $ poetry run airflow users create \\\n      --username admin \\\n      --firstname Peter \\\n      --lastname Parker \\\n      --role Admin \\\n      --email spiderman@superhero.org\n  \n  # Create example DVC DAGs\n  $ poetry run airflow_dvc generate example_dags\n  \n  # Run Airflow\n  $ poetry run airflow webserver --port 8080 &\n  $ poetry run airflow scheduler &\n```\n\n## Usage\n\n### 📊 DVC Operator view\n\nAfter installation, you should be able to access `Browse > DVC Operators` option in the Airflow menu.\n\n<img src="https://github.com/covid-genomics/airflow-dvc/blob/master/static/screen2.png?raw=true" width="400px"/>\n\nThe `DVC Operators` view allows you to display all configured DVC operators and repositories that they will push the files to/pull from.\n\n<img src="https://github.com/covid-genomics/airflow-dvc/blob/master/static/screen1.png?raw=true" width="800px"/>\n\nThe `DVC Pushes` view allows you to display all commits created by the DVC operators among all repositories:\n\n<img src="https://github.com/covid-genomics/airflow-dvc/blob/master/static/screen3.png?raw=true" width="800px"/>\n\n\n### 💾 DVCUpdateOperator (Uploading)\n\nThe upload operator supports various types of data inputs that you can feed into it.\n\n**Uploading a string as a file:**\n```python\n    from airflow_dvc import DVCUpdateOperator, DVCStringUpload\n    from datetime import datetime\n\n    upload_task = DVCUpdateOperator(\n        dvc_repo="<REPO_CLONE_URL>",\n        files=[\n            DVCStringUpload("data/1.txt", f"This will be saved into DVC. Current time: {datetime.now()}"),\n        ],\n        task_id=\'update_dvc\',\n    )\n```\n\n**Uploading local file using its path:**\n```python\n    from airflow_dvc import DVCUpdateOperator, DVCPathUpload\n\n    upload_task = DVCUpdateOperator(\n        dvc_repo="<REPO_CLONE_URL>",\n        files=[\n            DVCPathUpload("data/1.txt", "~/local_file_path.txt"),\n        ],\n        task_id=\'update_dvc\',\n    )\n```\n\n**Upload content generated by a python function:**\n```python\n    from airflow_dvc import DVCUpdateOperator, DVCCallbackUpload\n\n    upload_task = DVCUpdateOperator(\n        dvc_repo="<REPO_CLONE_URL>",\n        files=[\n            DVCCallbackUpload("data/1.txt", lambda: "Test data"),\n        ],\n        task_id=\'update_dvc\',\n    )\n```\n\n**Uploading file from S3:**\nThis is specially useful when you have a workflow that uses [S3Hook](https://airflow.apache.org/docs/apache-airflow/1.10.14/_modules/airflow/hooks/S3_hook.html) to temporarily save the data between tasks.\n\n```python\nfrom airflow import DAG\nfrom airflow.operators.python_operator import PythonOperator\nfrom airflow.providers.amazon.aws.hooks.s3 import S3Hook\nfrom datetime import datetime, timedelta\n\nfrom io import StringIO\nimport pandas as pd\nimport requests\n\nfrom airflow_dvc import DVCUpdateOperator, DVCS3Upload\n\ns3_conn_id = \'s3-conn\'\nbucket = \'astro-workshop-bucket\'\nstate = \'wa\'\ndate = \'{{ yesterday_ds_nodash }}\'\n\ndef upload_to_s3(state, date):\n    \'\'\'Grabs data from Covid endpoint and saves to flat file on S3\n    \'\'\'\n    # Connect to S3\n    s3_hook = S3Hook(aws_conn_id=s3_conn_id)\n\n    # Get data from API\n    url = \'https://covidtracking.com/api/v1/states/\'\n    res = requests.get(url+\'{0}/{1}.csv\'.format(state, date))\n\n    # Save data to CSV on S3\n    s3_hook.load_string(res.text, \'{0}_{1}.csv\'.format(state, date), bucket_name=bucket, replace=True)\n\ndef process_data(state, date):\n    \'\'\'Reads data from S3, processes, and saves to new S3 file\n    \'\'\'\n    # Connect to S3\n    s3_hook = S3Hook(aws_conn_id=s3_conn_id)\n\n    # Read data\n    data = StringIO(s3_hook.read_key(key=\'{0}_{1}.csv\'.format(state, date), bucket_name=bucket))\n    df = pd.read_csv(data, sep=\',\')\n\n    # Process data\n    processed_data = df[[\'date\', \'state\', \'positive\', \'negative\']]\n\n    # Save processed data to CSV on S3\n    s3_hook.load_string(processed_data.to_string(), \'dvc_upload.csv\', bucket_name=bucket, replace=True)\n\n# Default settings applied to all tasks\ndefault_args = {\n    \'owner\': \'airflow\',\n    \'depends_on_past\': False,\n    \'email_on_failure\': False,\n    \'email_on_retry\': False,\n    \'retries\': 1,\n    \'retry_delay\': timedelta(minutes=1)\n}\n\nwith DAG(\'intermediary_data_storage_dag\',\n         start_date=datetime(2021, 1, 1),\n         max_active_runs=1,\n         schedule_interval=\'@daily\',\n         default_args=default_args,\n         catchup=False\n         ) as dag:\n\n    generate_file = PythonOperator(\n        task_id=\'generate_file_{0}\'.format(state),\n        python_callable=upload_to_s3,\n        op_kwargs={\'state\': state, \'date\': date}\n    )\n\n    process_data = PythonOperator(\n        task_id=\'process_data_{0}\'.format(state),\n        python_callable=process_data,\n        op_kwargs={\'state\': state, \'date\': date}\n    )\n    \n    upload_to_dvc = DVCUpdateOperator(\n        dvc_repo="<REPO_CLONE_URL>",\n        files=[\n            DVCS3Upload("dvc_path/data.txt", s3_conn_id, bucket, \'dvc_upload.csv\'),\n        ],\n        task_id=\'update_dvc\',\n    )\n\n    generate_file >> process_data\n    process_data >> upload_to_dvc\n```\n\n**Uploading file from S3, but using task arguments:**\nInstead of passing list as a files parameter you can pass function as would do in case of PythonOperator:\n```python\nfrom airflow import DAG\nfrom airflow.operators.python_operator import PythonOperator\nfrom airflow.providers.amazon.aws.hooks.s3 import S3Hook\nfrom datetime import datetime, timedelta\n\nfrom io import StringIO\nimport pandas as pd\nimport requests\n\nfrom airflow_dvc import DVCUpdateOperator, DVCS3Upload\n\ns3_conn_id = \'s3-conn\'\nbucket = \'astro-workshop-bucket\'\nstate = \'wa\'\ndate = \'{{ yesterday_ds_nodash }}\'\n\ndef upload_to_s3(state, date):\n    \'\'\'Grabs data from Covid endpoint and saves to flat file on S3\n    \'\'\'\n    # Connect to S3\n    s3_hook = S3Hook(aws_conn_id=s3_conn_id)\n\n    # Get data from API\n    url = \'https://covidtracking.com/api/v1/states/\'\n    res = requests.get(url+\'{0}/{1}.csv\'.format(state, date))\n\n    # Save data to CSV on S3\n    s3_hook.load_string(res.text, \'{0}_{1}.csv\'.format(state, date), bucket_name=bucket, replace=True)\n\ndef process_data(state, date):\n    \'\'\'Reads data from S3, processes, and saves to new S3 file\n    \'\'\'\n    # Connect to S3\n    s3_hook = S3Hook(aws_conn_id=s3_conn_id)\n\n    # Read data\n    data = StringIO(s3_hook.read_key(key=\'{0}_{1}.csv\'.format(state, date), bucket_name=bucket))\n    df = pd.read_csv(data, sep=\',\')\n\n    # Process data\n    processed_data = df[[\'date\', \'state\', \'positive\', \'negative\']]\n\n    # Save processed data to CSV on S3\n    s3_hook.load_string(processed_data.to_string(), \'{0}_{1}_processed.csv\'.format(state, date), bucket_name=bucket, replace=True)\n\ndef get_files_for_upload(state, date):\n    return [\n        DVCS3Upload("dvc_path/data.txt", s3_conn_id, bucket, \'{0}_{1}_processed.csv\'.format(state, date)),\n    ]\n    \n# Default settings applied to all tasks\ndefault_args = {\n    \'owner\': \'airflow\',\n    \'depends_on_past\': False,\n    \'email_on_failure\': False,\n    \'email_on_retry\': False,\n    \'retries\': 1,\n    \'retry_delay\': timedelta(minutes=1)\n}\n\nwith DAG(\'intermediary_data_storage_dag\',\n         start_date=datetime(2021, 1, 1),\n         max_active_runs=1,\n         schedule_interval=\'@daily\',\n         default_args=default_args,\n         catchup=False\n         ) as dag:\n\n    generate_file = PythonOperator(\n        task_id=\'generate_file_{0}\'.format(state),\n        python_callable=upload_to_s3,\n        op_kwargs={\'state\': state, \'date\': date}\n    )\n\n    process_data = PythonOperator(\n        task_id=\'process_data_{0}\'.format(state),\n        python_callable=process_data,\n        op_kwargs={\'state\': state, \'date\': date}\n    )\n    \n    # Passing a function as files paramterer (it sould return a list of DVCUpload objects)\n    # Also we specify op_kwargs to allow passing of parameters as in case of normal PythonOperator\n    upload_to_dvc = DVCUpdateOperator(\n        dvc_repo="<REPO_CLONE_URL>",\n        files=get_files_for_upload,\n        task_id=\'update_dvc\',\n        op_kwargs={\'state\': state, \'date\': date}\n    )\n\n    generate_file >> process_data\n    process_data >> upload_to_dvc\n```\n\n### ⬇️ DVCDownloadOperator (Downloading)\n\nWe can use `VCDownloadOperator` similarily to the `DVCUpdateOperator`. The syntax is the same:\n```python\n    from airflow_dvc import DVCDownloadOperator, DVCCallbackDownload\n\n    # Download DVC file data/1.txt and print it on the screen\n    upload_task = DVCDownloadOperator(\n        dvc_repo="<REPO_CLONE_URL>",\n        files=[\n            DVCCallbackDownload("data/1.txt", lambda content: print(content)),\n        ],\n        task_id=\'update_dvc\',\n    )\n```\n\nThe `DVCDownload` implementations are similar to `DVCUpload`.\n\n### 👀 DVCSensor\n\n`DVCSensor` will allow you to pause the DAG run until the specified file will be updated.\nThe sensor checks the date of the latest DAG run and compares it with timestamp of meta DVC file in the repo.\n\n```python\nfrom datetime import datetime\nfrom airflow import DAG\nfrom airflow.operators.dummy_operator import DummyOperator\nfrom airflow.operators.bash_operator import BashOperator\n\nfrom airflow_dvc import DVCUpdateSensor\n\n\nwith DAG(\'dvc_sensor_example\', description=\'Another tutorial DAG\',\n    start_date=datetime(2017, 3, 20),\n    catchup=False,\n) as dag:\n\n    dummy_task = DummyOperator(task_id=\'dummy_task\', dag=dag)\n\n    sensor_task = DVCUpdateSensor(\n        task_id=\'dvc_sensor_task\',\n        dag=dag,\n        dvc_repo="<REPO_CLONE_URL>",\n        files=["data/1.txt"],\n    )\n\n    task = BashOperator(\n        task_id=\'task_triggered_by_sensor\',\n        bash_command=\'echo "OK" && ( echo $[ ( $RANDOM % 30 )  + 1 ] > meowu.txt ) && cat meowu.txt\')\n\n    dummy_task >> sensor_task >> task\n\n```\n\n### 🤖 DVCHook\n\nYou can perform all the operation manually using DVCHook:\n```python\nfrom airflow_dvc import DVCHook, DVCPathUpload\n\nhook = DVCHook("<REPO_URL>")\n\n# Hook requires dag_id so if we will run this code inside class extending any Operator\n# we will be able to access self.dag_id field\n# Dag IDs are used to track all pushes to your DVC repositories\nhook.update([\n    DVCPathUpload("data/1.txt", "~/local_file_path.txt"),\n], dag_id=self.dag_id)\n```\n## Development\n\nInstall the project with the following command:\n```python\n    $ poetry install\n```\n\n* You may want to run `poetry --version` to check if you have [Poetry](https://python-poetry.org/docs/) installed. If the command fails then proceed to install Poetry. The installer installs the poetry tool to Poetry\'s bin directory. On Unix it is located at `$HOME/.poetry/bin` and on Windows at `%USERPROFILE%\\.poetry\\bin`.\nThis directory will be automatically added to your `$PATH` environment variable, by appending a statement to your `$HOME/.profile` configuration (or equivalent files). If you do not feel comfortable with this, please pass the --no-modify-path flag to the installer and manually add the Poetry\'s bin directory to your path.\n    * **Linux/Mac:** `curl -sSL https://raw.githubusercontent.com/python-poetry/poetry/master/get-poetry.py | python -`\n    * **Windows:** Type in Powershell: `(Invoke-WebRequest -Uri https://raw.githubusercontent.com/python-poetry/poetry/master/get-poetry.py -UseBasicParsing).Content | python `\n* Install project with `poetry install`\n* You can now use virtual env created by poetry. Please type `poetry shell`\n\n### Code style\n\nThe project has configured styles in `pyproject.toml`.\nTo format it please call `make lint`.\n\n### Versioning\n\nTo bump project version before release please use the following command (for developers):\n```bash\n    $ poetry run bump2version minor\n```\n',
    'author': 'Piotr Styczyński',
    'author_email': 'piotrsty1@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
